# PyPap3r

A python package that can change a mac's wallpaper from a url or file.

# Usage

## Importing the package

```python
from PyPap3r import wallpaper_url, wallpaper_file
```

## Wallpaper from url

```python
wallpaper_url('https://www.thebaconpug.com/css/img/background.jpg')
```
## Wallpaper from file

```python
wallpaper_file('file path here')
```